******************************************************
*  Replication excercise for EUP forum

* NOTE:  I use the data file ams_jbs_temp.dta ready for being used by Slapin's do file probit_indiff_103006.do
* PLEASE REFER TO REPLICATION DATA AVAILABLE FROM Slapin's IO article

clear 
version 8.2

*load data

use "ams_jbs_temp.dta", clear

***********************************************************************
**** Same procedure as in Slapin's do file probit_indiff_103006.do
* First transform data so sq always equals 0
* Now preferences do not reflect an integrationalist position

replace com= abs(com-sq) if sq~=0     
replace ep= abs(ep-sq) if sq~=0
replace b= abs(b-sq) if sq~=0
replace dk= abs(dk-sq) if sq~=0
replace d= abs(d-sq) if sq~=0
replace gr= abs(gr-sq) if sq~=0
replace e= abs(e-sq) if sq~=0
replace f= abs(f-sq) if sq~=0
replace irl= abs(irl-sq) if sq~=0
replace i= abs(i-sq) if sq~=0
replace lux= abs(lux-sq) if sq~=0
replace nl= abs(nl-sq) if sq~=0
replace a= abs(a-sq) if sq~=0
replace p= abs(p-sq) if sq~=0
replace sf= abs(sf-sq) if sq~=0
replace s= abs(s-sq) if sq~=0
replace uk= abs(uk-sq) if sq~=0
replace am= abs(am-sq) if sq~=0
replace sq=0 if sq~=0

***********************************************************************
**** Same procedure as in Slapin's do file probit_indiff_103006.do
* Here I count number missing by member state
* I create a dummy variable to indicate whether each member state is 
* missing on an issue. I then sum the dummy variables.

gen missdumb=1 if b==.
replace missdumb=0 if missdumb==.

gen missdumdk=1 if dk==.
replace missdumdk=0 if missdumdk==.

gen missdumd=1 if d==.
replace missdumd=0 if missdumd==.

gen missdumgr=1 if gr==.
replace missdumgr=0 if missdumgr==.

gen missdume=1 if e==.
replace missdume=0 if missdume==.

gen missdumf=1 if f==.
replace missdumf=0 if missdumf==.

gen missdumirl=1 if irl==.
replace missdumirl=0 if missdumirl==.

gen missdumi=1 if i==.
replace missdumi=0 if missdumi==.

gen missdumlux=1 if lux==.
replace missdumlux=0 if missdumlux==.

gen missdumnl=1 if nl==.
replace missdumnl=0 if missdumnl==.

gen missduma=1 if a==.
replace missduma=0 if missduma==.

gen missdump=1 if p==.
replace missdump=0 if missdump==.

gen missdumsf=1 if sf==.
replace missdumsf=0 if missdumsf==.

gen missdums=1 if s==.
replace missdums=0 if missdums==.

gen missdumuk=1 if uk==.
replace missdumuk=0 if missdumuk==.

gen nummiss=missdumb+missdumdk+missdumd+missdumgr /*
*/+missdume+missdumf+missdumirl+missdumi+missdumlux+/*
*/missdumnl+missduma+missdump+missdumsf+missdums+missdumuk


**********************************************************************************
**** Same procedure as in Slapin's do file probit_indiff_103006.do
* Now I consider only true status quo positions, not missing positions

gen sqdumb=1 if b==sq
replace sqdumb=0 if sqdumb==.

gen sqdumdk=1 if dk==sq
replace sqdumdk=0 if sqdumdk==.

gen sqdumd=1 if d==sq
replace sqdumd=0 if sqdumd==.

gen sqdumgr=1 if gr==sq
replace sqdumgr=0 if sqdumgr==.

gen sqdume=1 if e==sq
replace sqdume=0 if sqdume==.

gen sqdumf=1 if f==sq
replace sqdumf=0 if sqdumf==.

gen sqdumirl=1 if irl==sq
replace sqdumirl=0 if sqdumirl==.

gen sqdumi=1 if i==sq
replace sqdumi=0 if sqdumi==.

gen sqdumlux=1 if lux==sq
replace sqdumlux=0 if sqdumlux==.

gen sqdumnl=1 if nl==sq
replace sqdumnl=0 if sqdumnl==.

gen sqduma=1 if a==sq
replace sqduma=0 if sqduma==.

gen sqdump=1 if p==sq
replace sqdump=0 if sqdump==.

gen sqdumsf=1 if sf==sq
replace sqdumsf=0 if sqdumsf==.

gen sqdums=1 if s==sq
replace sqdums=0 if sqdums==.

gen sqdumuk=1 if uk==sq
replace sqdumuk=0 if sqdumuk==.

* This variable takes the value of 1 if all states are for reform, 0 otherwise
gen s_veto=1
replace s_veto=0 if sqdumb==1 | sqdumdk==1 | sqdumd==1 | sqdumgr==1 | sqdume==1 | sqdumf==1 | sqdumirl==1 /*
*/ | sqdumi==1 | sqdumlux==1 | sqdumnl==1 | sqduma==1 | sqdump==1 | sqdumsf==1 | sqdums==1 | sqdumuk==1

**********************************************************************************
**** Same procedure as in Slapin's do file probit_indiff_103006.do
* Here I choose Slapin's general assumption about missing preferences == SQ

replace com= sq if com==.
replace ep= sq if ep==.
replace b= sq if b==.
replace dk= sq if dk==.
replace d= sq if d==.
replace gr= sq if gr==.
replace e= sq if e==.
replace f= sq if f==.
replace irl= sq if irl==.
replace i= sq if i==.
replace lux= sq if lux==.
replace nl= sq if nl==.
replace a= sq if a==.
replace p= sq if p==.
replace sf= sq if sf==.
replace s= sq if s==.
replace uk= sq if uk==.

* This variable takes the value of 1 if all states are for reform, 0 otherwise (but now missing preferences == SQ)
gen s_veto1=1
replace s_veto1=0 if b==sq | dk==sq | d==sq | gr==sq | e==sq | f==sq | irl==sq /*
*/ | i==sq | lux==sq | nl==sq | a==sq | p==sq | sf==sq | s==sq | uk==sq

********************************************************
* Here I rescale all prefs from -1 to 1

replace sq= -1 
replace b= 2*b-1
replace dk= 2*dk-1
replace d= 2*d-1
replace gr= 2*gr-1
replace e= 2*e-1
replace f= 2*f-1
replace irl= 2*irl-1
replace i= 2*i-1
replace lux= 2*lux-1
replace nl= 2*nl-1
replace a= 2*a-1
replace p= 2*p-1
replace sf= 2*sf-1
replace s= 2*s-1
replace uk= 2*uk-1

*  Here I generate the preference variable where Missing = SQ (as Model 2 in Slapin, p.79, but unweighted)

gen pref = b + dk + d + gr + e + f + irl + i + lux + nl + a + p + sf + s + uk

* Here I recode missdum vars so missing is 0 and present is 1

recode missdumb missdumdk missdumd missdumgr /*
*/ missdume missdumf missdumirl missdumi missdumlux /*
*/missdumnl missduma missdump missdumsf missdums missdumuk /*
*/ (0=1)(1=0)

*  Here I generate the saliency-weighted preference variable where Missing = SQ and Missing = Low Saliency 
*  (as in Model 3 in Slapin, p.79, low salience is equivalent to indifference between SQ and inclusion)

gen s_pref = (missdumb * b) + (missdumdk * dk) + (missdumd * d) + (missdumgr * gr) + /*
*/ (missdume * e) + (missdumf * f) + (missdumirl * irl) + (missdumi * i) + (missdumlux * lux) + /*
*/(missdumnl * nl) + (missduma * a) + (missdump * p) + (missdumsf * sf) + (missdums * s) + (missdumuk *uk)


**********************************************************************************
**** Same procedure as in Slapin's do file probit_indiff_103006.do
* gdp as a measure of capabilities
* 1997 GDP taken from Eurostat 3/14/06. Denominated in thousands of Euros
* calculated as member state gdp over total EU 15 GDP

gen gdpb=220129.4
gen gdpdk=150414.1
gen gdpd=1907246.2
gen gdpgr=107103.0
gen gdpe=505391.7
gen gdpf=1258310.6
gen gdpirl=71717.6
gen gdpi=1052553.8
gen gdplux=15417.1
gen gdpnl=332653.9
gen gdpa=184287.1
gen gdpp=98831.3
gen gdpsf=109075
gen gdps=220161.8
gen gdpuk=1170875.1

gen gdptot=gdpb+gdpdk+gdpd+gdpgr+gdpe+gdpf+gdpirl+gdpi+gdplux+gdpnl+gdpa+gdpp+gdpsf+gdps+gdpuk

 gen vsb=gdpb/gdptot
 gen vsdk=gdpdk/gdptot
 gen vsd=gdpd/gdptot
 gen vsgr=gdpgr/gdptot
 gen vse=gdpe/gdptot
 gen vsf=gdpf/gdptot
 gen vsirl=gdpirl/gdptot
 gen vsi=gdpi/gdptot
 gen vslux=gdplux/gdptot
 gen vsnl=gdpnl/gdptot
 gen vsa=gdpa/gdptot
 gen vsp=gdpp/gdptot
 gen vssf=gdpsf/gdptot
 gen vss=gdps/gdptot
 gen vsuk=gdpuk/gdptot

**************************************************************************
*  Here I generate the capability-and-saliency-weighted preference variable where Missing = SQ and Missing = Low Saliency 
*  (as in Model 3 in Slapin, p.79, low salience is equivalent to indifference between SQ and inclusion)

gen cs_pref = (vsb* missdumb * b) + (vsdk * missdumdk * dk) + (vsd * missdumd * d) + (vsgr * missdumgr * gr) + /*
*/ (vse * missdume * e) + (vsf * missdumf * f) + (vsirl * missdumirl * irl) + (vsi * missdumi * i) + (vslux * missdumlux * lux) + /*
*/(vsnl * missdumnl * nl) + (vsa * missduma * a) + (vsp * missdump * p) + (vsf * missdumsf * sf) + (vss * missdums * s) + (vsuk * missdumuk *uk)

*  Here I generate an alternative capability-and-saliency-weighted preference variable where Missing = SQ and Missing = Low Saliency 
*  and capability is Council votes

gen cs_pref1 = (5 * missdumb * b) + (3 * missdumdk * dk) + (10 * missdumd * d) + (5 * missdumgr * gr) + /*
*/ (8 * missdume * e) + (10 * missdumf * f) + (3 * missdumirl * irl) + (10 * missdumi * i) + (2 * missdumlux * lux) + /*
*/(5 * missdumnl * nl) + (4 * missduma * a) + (5 * missdump * p) + (3 * missdumsf * sf) + (4 * missdums * s) + (10 * missdumuk *uk)

exit

***********************************
***** These are the four models

* single veto: s_veto
glm am s_veto, family(bin) link(probit) robust

* unwieghted: pref
glm am pref, family(bin) link(probit) robust

* salience-weighted: s_pref
glm am s_pref, family(bin) link(probit) robust

* salience-capability-weighted: cs_pref
glm am cs_pref, family(bin) link(probit) robust

************************ J-Tests for Table 1
****** J-Tests   pref vs s_veto
* alternative model (pref)
glm am pref, family(bin) link(probit) robust
predict yhat
* null model (s_veto)
glm am s_veto yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (s_veto)
glm am s_veto, family(bin) link(probit) robust
predict yhat
* null model (pref)
glm am pref yhat, family(bin) link(probit) robust

****** J-Tests   s_pref vs s_veto
* alternative model (s_pref)
drop yhat
glm am s_pref, family(bin) link(probit) robust
predict yhat
* null model (s_veto)
glm am s_veto yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (s_veto)
glm am s_veto, family(bin) link(probit) robust
predict yhat
* null model (s_pref)
glm am s_pref yhat, family(bin) link(probit) robust

****** J-Tests   cs_pref vs s_veto
* alternative model (cs_pref)
drop yhat
glm am cs_pref, family(bin) link(probit) robust
predict yhat
* null model (s_veto)
glm am s_veto yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (s_veto)
glm am s_veto, family(bin) link(probit) robust
predict yhat
* null model (cs_pref)
glm am cs_pref yhat, family(bin) link(probit) robust

****** J-Tests   pref vs s_pref
* alternative model (s_pref)
drop yhat
glm am s_pref, family(bin) link(probit) robust
predict yhat
* null model (pref)
glm am pref yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (pref)
glm am pref, family(bin) link(probit) robust
predict yhat
* null model (s_pref)
glm am s_pref yhat, family(bin) link(probit) robust

****** J-Tests   pref vs cs_pref
* alternative model (cs_pref)
drop yhat
glm am cs_pref, family(bin) link(probit) robust
predict yhat
* null model (pref)
glm am pref yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (pref)
glm am pref, family(bin) link(probit) robust
predict yhat
* null model (cs_pref)
glm am cs_pref yhat, family(bin) link(probit) robust

****** J-Tests   s_pref vs cs_pref
* alternative model (cs_pref)
drop yhat
glm am cs_pref, family(bin) link(probit) robust
predict yhat
* null model (s_pref)
glm am s_pref yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (s_pref)
glm am s_pref, family(bin) link(probit) robust
predict yhat
* null model (cs_pref)
glm am cs_pref yhat, family(bin) link(probit) robust

****************** More J-Tests with s_veto1
* alternative model (pref)
glm am pref, family(bin) link(probit) robust
predict yhat
* null model (s_veto1)
glm am s_veto1 yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (s_veto1)
glm am s_veto1, family(bin) link(probit) robust
predict yhat
* null model (pref)
glm am pref yhat, family(bin) link(probit) robust

****** J-Tests   s_pref vs s_veto1
* alternative model (s_pref)
drop yhat
glm am s_pref, family(bin) link(probit) robust
predict yhat
* null model (s_veto1)
glm am s_veto1 yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (s_veto1)
glm am s_veto1, family(bin) link(probit) robust
predict yhat
* null model (s_pref)
glm am s_pref yhat, family(bin) link(probit) robust

****** J-Tests   cs_pref vs s_veto1
* alternative model (cs_pref)
drop yhat
glm am cs_pref, family(bin) link(probit) robust
predict yhat
* null model (s_veto1)
glm am s_veto1 yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (s_veto1)
glm am s_veto1, family(bin) link(probit) robust
predict yhat
* null model (cs_pref)
glm am cs_pref yhat, family(bin) link(probit) robust

****************** More J-Tests with cs_pref1
****** J-Tests   cs_pref1 vs s_veto
* alternative model (cs_pref1)
drop yhat
glm am cs_pref1, family(bin) link(probit) robust
predict yhat
* null model (s_veto)
glm am s_veto yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (s_veto)
glm am s_veto, family(bin) link(probit) robust
predict yhat
* null model (cs_pref1)
glm am cs_pref1 yhat, family(bin) link(probit) robust

****** J-Tests   pref vs cs_pref1
* alternative model (cs_pref1)
drop yhat
glm am cs_pref1, family(bin) link(probit) robust
predict yhat
* null model (pref)
glm am pref yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (pref)
glm am pref, family(bin) link(probit) robust
predict yhat
* null model (cs_pref1)
glm am cs_pref1 yhat, family(bin) link(probit) robust

****** J-Tests   s_pref vs cs_pref1
* alternative model (cs_pref1)
drop yhat
glm am cs_pref1, family(bin) link(probit) robust
predict yhat
* null model (s_pref)
glm am s_pref yhat, family(bin) link(probit) robust
*
drop yhat
* alternative model (s_pref)
glm am s_pref, family(bin) link(probit) robust
predict yhat
* null model (cs_pref1)
glm am cs_pref1 yhat, family(bin) link(probit) robust





